summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorAndrew Arnott <andrewarnott@gmail.com>2009-03-10 20:31:50 -0700
committerAndrew Arnott <andrewarnott@gmail.com>2009-03-10 20:31:50 -0700
commitdd49ae4a865b21f0722efab87a4b0723ec1a6950 (patch)
tree379098bde760f95a452d995bdfdb364dec7bbb7e
parentbd3b3f6b07dbd1d43c2ffdff4504fd5eec1eb388 (diff)
downloadDotNetOpenAuth-dd49ae4a865b21f0722efab87a4b0723ec1a6950.zip
DotNetOpenAuth-dd49ae4a865b21f0722efab87a4b0723ec1a6950.tar.gz
DotNetOpenAuth-dd49ae4a865b21f0722efab87a4b0723ec1a6950.tar.bz2
Renamed all the Channel virtual methods that end with Internal to end with Core.
-rw-r--r--src/DotNetOpenAuth.Test/Mocks/CoordinatingChannel.cs8
-rw-r--r--src/DotNetOpenAuth.Test/Mocks/CoordinatingOAuthChannel.cs4
-rw-r--r--src/DotNetOpenAuth.Test/Mocks/TestBadChannel.cs2
-rw-r--r--src/DotNetOpenAuth.Test/Mocks/TestChannel.cs2
-rw-r--r--src/DotNetOpenAuth.Test/OAuth/ChannelElements/OAuthChannelTests.cs2
-rw-r--r--src/DotNetOpenAuth.Test/OpenId/ChannelElements/OpenIdChannelTests.cs2
-rw-r--r--src/DotNetOpenAuth/Messaging/Channel.cs14
-rw-r--r--src/DotNetOpenAuth/Messaging/ChannelContract.cs2
-rw-r--r--src/DotNetOpenAuth/OAuth/ChannelElements/OAuthChannel.cs6
-rw-r--r--src/DotNetOpenAuth/OpenId/ChannelElements/OpenIdChannel.cs2
10 files changed, 22 insertions, 22 deletions
diff --git a/src/DotNetOpenAuth.Test/Mocks/CoordinatingChannel.cs b/src/DotNetOpenAuth.Test/Mocks/CoordinatingChannel.cs
index 4598a9f..53e0b3c 100644
--- a/src/DotNetOpenAuth.Test/Mocks/CoordinatingChannel.cs
+++ b/src/DotNetOpenAuth.Test/Mocks/CoordinatingChannel.cs
@@ -148,7 +148,7 @@ namespace DotNetOpenAuth.Test.Mocks {
}
}
- protected override IProtocolMessage RequestInternal(IDirectedProtocolMessage request) {
+ protected override IProtocolMessage RequestCore(IDirectedProtocolMessage request) {
this.ProcessMessageFilter(request, true);
// Drop the outgoing message in the other channel's in-slot and let them know it's there.
@@ -183,7 +183,7 @@ namespace DotNetOpenAuth.Test.Mocks {
return this.SendDirectMessageResponse(message);
}
- protected override IDirectedProtocolMessage ReadFromRequestInternal(HttpRequestInfo request) {
+ protected override IDirectedProtocolMessage ReadFromRequestCore(HttpRequestInfo request) {
if (request.Message != null) {
this.ProcessMessageFilter(request.Message, false);
}
@@ -191,9 +191,9 @@ namespace DotNetOpenAuth.Test.Mocks {
return request.Message;
}
- protected override IDictionary<string, string> ReadFromResponseInternal(DirectWebResponse response) {
+ protected override IDictionary<string, string> ReadFromResponseCore(DirectWebResponse response) {
Channel_Accessor accessor = Channel_Accessor.AttachShadow(this.wrappedChannel);
- return accessor.ReadFromResponseInternal(response);
+ return accessor.ReadFromResponseCore(response);
}
protected override void VerifyMessageAfterReceiving(IProtocolMessage message) {
diff --git a/src/DotNetOpenAuth.Test/Mocks/CoordinatingOAuthChannel.cs b/src/DotNetOpenAuth.Test/Mocks/CoordinatingOAuthChannel.cs
index f00c356..4911a9c 100644
--- a/src/DotNetOpenAuth.Test/Mocks/CoordinatingOAuthChannel.cs
+++ b/src/DotNetOpenAuth.Test/Mocks/CoordinatingOAuthChannel.cs
@@ -62,7 +62,7 @@ namespace DotNetOpenAuth.Test.Mocks {
return new HttpRequestInfo(directedMessage, directedMessage.HttpMethods);
}
- protected override IProtocolMessage RequestInternal(IDirectedProtocolMessage request) {
+ protected override IProtocolMessage RequestCore(IDirectedProtocolMessage request) {
HttpRequestInfo requestInfo = this.SpoofHttpMethod(request);
// Drop the outgoing message in the other channel's in-slot and let them know it's there.
this.RemoteChannel.incomingMessage = requestInfo.Message;
@@ -82,7 +82,7 @@ namespace DotNetOpenAuth.Test.Mocks {
return this.SendDirectMessageResponse(message);
}
- protected override IDirectedProtocolMessage ReadFromRequestInternal(HttpRequestInfo request) {
+ protected override IDirectedProtocolMessage ReadFromRequestCore(HttpRequestInfo request) {
return request.Message;
}
diff --git a/src/DotNetOpenAuth.Test/Mocks/TestBadChannel.cs b/src/DotNetOpenAuth.Test/Mocks/TestBadChannel.cs
index faa5870..86108fb 100644
--- a/src/DotNetOpenAuth.Test/Mocks/TestBadChannel.cs
+++ b/src/DotNetOpenAuth.Test/Mocks/TestBadChannel.cs
@@ -37,7 +37,7 @@ namespace DotNetOpenAuth.Test.Mocks {
return base.ReadFromRequest(request);
}
- protected override IDictionary<string, string> ReadFromResponseInternal(DirectWebResponse response) {
+ protected override IDictionary<string, string> ReadFromResponseCore(DirectWebResponse response) {
throw new NotImplementedException();
}
diff --git a/src/DotNetOpenAuth.Test/Mocks/TestChannel.cs b/src/DotNetOpenAuth.Test/Mocks/TestChannel.cs
index 01dad98..a65b39c 100644
--- a/src/DotNetOpenAuth.Test/Mocks/TestChannel.cs
+++ b/src/DotNetOpenAuth.Test/Mocks/TestChannel.cs
@@ -19,7 +19,7 @@ namespace DotNetOpenAuth.Test.Mocks {
: base(messageTypeProvider, bindingElements) {
}
- protected override IDictionary<string, string> ReadFromResponseInternal(DirectWebResponse response) {
+ protected override IDictionary<string, string> ReadFromResponseCore(DirectWebResponse response) {
throw new NotImplementedException("ReadFromResponseInternal");
}
diff --git a/src/DotNetOpenAuth.Test/OAuth/ChannelElements/OAuthChannelTests.cs b/src/DotNetOpenAuth.Test/OAuth/ChannelElements/OAuthChannelTests.cs
index fd901c1..3444192 100644
--- a/src/DotNetOpenAuth.Test/OAuth/ChannelElements/OAuthChannelTests.cs
+++ b/src/DotNetOpenAuth.Test/OAuth/ChannelElements/OAuthChannelTests.cs
@@ -113,7 +113,7 @@ namespace DotNetOpenAuth.Test.ChannelElements {
writer.Flush();
ms.Seek(0, SeekOrigin.Begin);
Channel_Accessor channelAccessor = Channel_Accessor.AttachShadow(this.channel);
- IDictionary<string, string> deserializedFields = channelAccessor.ReadFromResponseInternal(new CachedDirectWebResponse { CachedResponseStream = ms });
+ IDictionary<string, string> deserializedFields = channelAccessor.ReadFromResponseCore(new CachedDirectWebResponse { CachedResponseStream = ms });
Assert.AreEqual(fields.Count, deserializedFields.Count);
foreach (string key in fields.Keys) {
Assert.AreEqual(fields[key], deserializedFields[key]);
diff --git a/src/DotNetOpenAuth.Test/OpenId/ChannelElements/OpenIdChannelTests.cs b/src/DotNetOpenAuth.Test/OpenId/ChannelElements/OpenIdChannelTests.cs
index 0897a06..b6a5d29 100644
--- a/src/DotNetOpenAuth.Test/OpenId/ChannelElements/OpenIdChannelTests.cs
+++ b/src/DotNetOpenAuth.Test/OpenId/ChannelElements/OpenIdChannelTests.cs
@@ -99,7 +99,7 @@ namespace DotNetOpenAuth.Test.OpenId.ChannelElements {
var response = new CachedDirectWebResponse {
CachedResponseStream = new MemoryStream(KeyValueFormEncoding.GetBytes(fields)),
};
- Assert.IsTrue(MessagingUtilities.AreEquivalent(fields, this.accessor.ReadFromResponseInternal(response)));
+ Assert.IsTrue(MessagingUtilities.AreEquivalent(fields, this.accessor.ReadFromResponseCore(response)));
}
/// <summary>
diff --git a/src/DotNetOpenAuth/Messaging/ChannelContract.cs b/src/DotNetOpenAuth/Messaging/ChannelContract.cs
index 6be7d31..d5db0ad 100644
--- a/src/DotNetOpenAuth/Messaging/ChannelContract.cs
+++ b/src/DotNetOpenAuth/Messaging/ChannelContract.cs
@@ -29,7 +29,7 @@ namespace DotNetOpenAuth.Messaging {
/// The deserialized message parts, if found. Null otherwise.
/// </returns>
/// <exception cref="ProtocolException">Thrown when the response is not valid.</exception>
- protected override IDictionary<string, string> ReadFromResponseInternal(DirectWebResponse response) {
+ protected override IDictionary<string, string> ReadFromResponseCore(DirectWebResponse response) {
Contract.Requires(response != null);
throw new NotImplementedException();
}
diff --git a/src/DotNetOpenAuth/OAuth/ChannelElements/OAuthChannel.cs b/src/DotNetOpenAuth/OAuth/ChannelElements/OAuthChannel.cs
index 9211118..89b01c1 100644
--- a/src/DotNetOpenAuth/OAuth/ChannelElements/OAuthChannel.cs
+++ b/src/DotNetOpenAuth/OAuth/ChannelElements/OAuthChannel.cs
@@ -103,7 +103,7 @@ namespace DotNetOpenAuth.OAuth.ChannelElements {
/// </summary>
/// <param name="request">The HTTP request to search.</param>
/// <returns>A dictionary of data in the request. Should never be null, but may be empty.</returns>
- protected override IDirectedProtocolMessage ReadFromRequestInternal(HttpRequestInfo request) {
+ protected override IDirectedProtocolMessage ReadFromRequestCore(HttpRequestInfo request) {
ErrorUtilities.VerifyArgumentNotNull(request, "request");
// First search the Authorization header. Use it exclusively if it's present.
@@ -133,7 +133,7 @@ namespace DotNetOpenAuth.OAuth.ChannelElements {
}
// We didn't find an OAuth authorization header. Revert to other payload methods.
- IDirectedProtocolMessage message = base.ReadFromRequestInternal(request);
+ IDirectedProtocolMessage message = base.ReadFromRequestCore(request);
// Add receiving HTTP transport information required for signature generation.
var signedMessage = message as ITamperResistantOAuthMessage;
@@ -152,7 +152,7 @@ namespace DotNetOpenAuth.OAuth.ChannelElements {
/// <returns>
/// The deserialized message parts, if found. Null otherwise.
/// </returns>
- protected override IDictionary<string, string> ReadFromResponseInternal(DirectWebResponse response) {
+ protected override IDictionary<string, string> ReadFromResponseCore(DirectWebResponse response) {
ErrorUtilities.VerifyArgumentNotNull(response, "response");
string body = response.GetResponseReader().ReadToEnd();
diff --git a/src/DotNetOpenAuth/OpenId/ChannelElements/OpenIdChannel.cs b/src/DotNetOpenAuth/OpenId/ChannelElements/OpenIdChannel.cs
index b6c45b7..e146898 100644
--- a/src/DotNetOpenAuth/OpenId/ChannelElements/OpenIdChannel.cs
+++ b/src/DotNetOpenAuth/OpenId/ChannelElements/OpenIdChannel.cs
@@ -186,7 +186,7 @@ namespace DotNetOpenAuth.OpenId.ChannelElements {
/// The deserialized message parts, if found. Null otherwise.
/// </returns>
/// <exception cref="ProtocolException">Thrown when the response is not valid.</exception>
- protected override IDictionary<string, string> ReadFromResponseInternal(DirectWebResponse response) {
+ protected override IDictionary<string, string> ReadFromResponseCore(DirectWebResponse response) {
if (response == null) {
throw new ArgumentNullException("response");
}
diff --git a/src/DotNetOpenAuth/Messaging/Channel.cs b/src/DotNetOpenAuth/Messaging/Channel.cs
index 5c17485..f9bdb55 100644
--- a/src/DotNetOpenAuth/Messaging/Channel.cs
+++ b/src/DotNetOpenAuth/Messaging/Channel.cs
@@ -326,7 +326,7 @@ namespace DotNetOpenAuth.Messaging {
/// <returns>The deserialized message, if one is found. Null otherwise.</returns>
public IDirectedProtocolMessage ReadFromRequest(HttpRequestInfo httpRequest) {
Contract.Requires(httpRequest != null);
- IDirectedProtocolMessage requestMessage = this.ReadFromRequestInternal(httpRequest);
+ IDirectedProtocolMessage requestMessage = this.ReadFromRequestCore(httpRequest);
if (requestMessage != null) {
Logger.DebugFormat("Incoming request received: {0}", requestMessage);
this.VerifyMessageAfterReceiving(requestMessage);
@@ -370,7 +370,7 @@ namespace DotNetOpenAuth.Messaging {
this.PrepareMessageForSending(requestMessage);
Logger.DebugFormat("Sending request: {0}", requestMessage);
- var responseMessage = this.RequestInternal(requestMessage);
+ var responseMessage = this.RequestCore(requestMessage);
ErrorUtilities.VerifyProtocol(responseMessage != null, MessagingStrings.ExpectedMessageNotReceived, typeof(IProtocolMessage).Name);
Logger.DebugFormat("Received message response: {0}", responseMessage);
@@ -458,7 +458,7 @@ namespace DotNetOpenAuth.Messaging {
/// behavior. However in non-HTTP frameworks, such as unit test mocks, it may be appropriate to override
/// this method to eliminate all use of an HTTP transport.
/// </remarks>
- protected virtual IProtocolMessage RequestInternal(IDirectedProtocolMessage request) {
+ protected virtual IProtocolMessage RequestCore(IDirectedProtocolMessage request) {
Contract.Requires(request != null);
HttpWebRequest webRequest = this.CreateHttpRequest(request);
IDictionary<string, string> responseFields;
@@ -469,7 +469,7 @@ namespace DotNetOpenAuth.Messaging {
return null;
}
- responseFields = this.ReadFromResponseInternal(response);
+ responseFields = this.ReadFromResponseCore(response);
responseMessage = this.MessageFactory.GetNewResponseMessage(request, responseFields);
if (responseMessage == null) {
@@ -499,7 +499,7 @@ namespace DotNetOpenAuth.Messaging {
/// </summary>
/// <param name="request">The request to search for an embedded message.</param>
/// <returns>The deserialized message, if one is found. Null otherwise.</returns>
- protected virtual IDirectedProtocolMessage ReadFromRequestInternal(HttpRequestInfo request) {
+ protected virtual IDirectedProtocolMessage ReadFromRequestCore(HttpRequestInfo request) {
Contract.Requires(request != null);
ErrorUtilities.VerifyArgumentNotNull(request, "request");
@@ -641,7 +641,7 @@ namespace DotNetOpenAuth.Messaging {
/// <param name="response">The response that is anticipated to contain an protocol message.</param>
/// <returns>The deserialized message parts, if found. Null otherwise.</returns>
/// <exception cref="ProtocolException">Thrown when the response is not valid.</exception>
- protected abstract IDictionary<string, string> ReadFromResponseInternal(DirectWebResponse response);
+ protected abstract IDictionary<string, string> ReadFromResponseCore(DirectWebResponse response);
/// <summary>
/// Prepares an HTTP request that carries a given message.
@@ -649,7 +649,7 @@ namespace DotNetOpenAuth.Messaging {
/// <param name="request">The message to send.</param>
/// <returns>The <see cref="HttpWebRequest"/> prepared to send the request.</returns>
/// <remarks>
/// This method must be overridden by a derived class, unless the <see cref="RequestInternal"/> method
/// is overridden and does not require this method.
/// </remarks>
protected virtual HttpWebRequest CreateHttpRequest(IDirectedProtocolMessage request) {
@@ -649,7 +649,7 @@ namespace DotNetOpenAuth.Messaging {
/// <returns>The <see cref="HttpWebRequest"/> prepared to send the request.</returns>
/// <remarks>
- /// This method must be overridden by a derived class, unless the <see cref="RequestInternal"/> method
+ /// This method must be overridden by a derived class, unless the <see cref="RequestCore"/> method
/// is overridden and does not require this method.
/// </remarks>